pub enum ButtonStyle {
Default,
Primary,
Danger,
}Expand description
The enumerated value that represents the button style.
Variants
Default
No value in the field.
Primary
primary gives buttons a green outline and text, ideal for affirmation or confirmation actions.
Danger
danger gives buttons a red outline and text, and should be used when the action is destructive.
Implementations
Sourceimpl ButtonStyle
impl ButtonStyle
Sourcepub fn is_default(&self) -> bool
pub fn is_default(&self) -> bool
Returns true if the ButtonStyle is ButtonStyle::Default.