pub enum ChatPostMessageContent {
Attachments(Vec<Attachments>),
Blocks(Vec<Block>),
Text(String),
}Expand description
The type that represents a selection of ChatPostMessageRequest::content.
Variants
Attachments(Vec<Attachments>)
A JSON-based array of structured attachments, presented as a URL-encoded string.
https://api.slack.com/methods/chat.postMessage#arg_attachments
Blocks(Vec<Block>)
A JSON-based array of structured blocks, presented as a URL-encoded string.
Text(String)
How this field works and whether it is required depends on other fields you use in your API call.