pub enum RichTextElement {
Broadcast(RichTextElementBroadcast),
Color(RichTextElementColor),
Channel(RichTextElementChannel),
Date(RichTextElementDate),
Emoji(RichTextElementEmoji),
Link(RichTextElementLink),
Text(RichTextElementText),
User(RichTextElementUser),
Usergroup(RichTextElementUsergroup),
}Expand description
Rich text element types.
https://api.slack.com/reference/block-kit/blocks#element-types
Variants
Broadcast(RichTextElementBroadcast)
The following are the properties of the broadcast object type in the elements array.
Color(RichTextElementColor)
The following are the properties of the color object type in the elements array.
Channel(RichTextElementChannel)
The following are the properties of the channel object type in the elements array.
Date(RichTextElementDate)
The following are the properties of the date object type in the elements array.
Emoji(RichTextElementEmoji)
The following are the properties of the emoji object type in the elements array.
Link(RichTextElementLink)
The following are the properties of the link object type in the elements array.
Text(RichTextElementText)
The following are the properties of the text object type in the elements array.
User(RichTextElementUser)
The following are the properties of the user object type in the elements array.
Usergroup(RichTextElementUsergroup)
The following are the properties of the usergroup object type in the elements array.