Struct sfr_types::ButtonElement
source · pub struct ButtonElement {
pub text: TextObject,
pub action_id: Option<ActionId>,
pub url: Option<String>,
pub value: Option<String>,
pub style: ButtonStyle,
pub confirm: Option<ConfirmObect>,
}Expand description
Button element.
https://api.slack.com/reference/block-kit/block-elements#button
Fields
text: TextObjectA text object that defines the button’s text.
action_id: Option<ActionId>An identifier for this action.
url: Option<String>A URL to load in the user’s browser when the button is clicked.
value: Option<String>The value to send along with the interaction payload.
style: ButtonStyleprimary gives buttons a green outline and text, ideal for affirmation or confirmation actions.
confirm: Option<ConfirmObect>A confirm object that defines an optional confirmation dialog after the button is clicked.