Struct sfr_types::ConfirmObect
source · pub struct ConfirmObect {
pub title: PlainTextObject,
pub text: TextObject,
pub confirm: PlainTextObject,
pub deny: PlainTextObject,
pub style: ButtonStyle,
}Expand description
The type that represents a confirmation dialog object.
Defines a dialog that adds a confirmation step to interactive elements.
https://api.slack.com/reference/block-kit/composition-objects#confirm
Fields
title: PlainTextObjectA plain_text text object that defines the dialog’s title.
text: TextObjectA plain_text text object that defines the explanatory text that appears in the confirm dialog.
confirm: PlainTextObjectA plain_text text object to define the text of the button that confirms the action.
deny: PlainTextObjectA plain_text text object to define the text of the button that cancels the action.
style: ButtonStyleDefines the color scheme applied to the confirm button.