Struct sfr_types::ImageBlock
source · pub struct ImageBlock {
pub alt_text: String,
pub image_url: Option<Url>,
pub title: Option<TextObject>,
pub block_id: Option<BlockId>,
}Expand description
Fields
alt_text: StringA plain-text summary of the image.
image_url: Option<Url>The URL for a publicly hosted image.
title: Option<TextObject>An optional title for the image in the form of a text object that can only be of type: plain_text.
block_id: Option<BlockId>A unique identifier for a block.