pub struct InputBlock {
pub label: TextObject,
pub element: Element,
pub dispatch_action: Option<bool>,
pub block_id: Option<BlockId>,
pub hint: Option<TextObject>,
pub optional: Option<bool>,
}Expand description
Fields
label: TextObjectA label that appears above an input element in the form of a text object that must have type of plain_text.
element: ElementA block element.
dispatch_action: Option<bool>A boolean that indicates whether or not the use of elements in this block should dispatch a block_actions payload.
block_id: Option<BlockId>A unique identifier for a block.
hint: Option<TextObject>An optional hint that appears below an input element in a lighter grey.
optional: Option<bool>A boolean that indicates whether the input element may be empty when a user submits the modal.