pub struct MessagePayloads {
pub text: String,
pub blocks: Vec<Block>,
pub attachments: Vec<String>,
pub thread_ts: Option<String>,
pub mrkdwn: Option<bool>,
}Expand description
Message payloads.
Fields
text: StringThe usage of this field changes depending on whether you’re using blocks or not.
blocks: Vec<Block>An array of layout blocks in the same format as described in the building blocks guide.
attachments: Vec<String>An array of legacy secondary attachments.
thread_ts: Option<String>The ID of another un-threaded message to reply to.
mrkdwn: Option<bool>Determines whether the text field is rendered according to mrkdwn formatting or not.