pub struct RichTextElementChannel {
pub channel_id: String,
pub style: Option<RichTextStyle2>,
}Expand description
The following are the properties of the channel object type in the elements array.
Fields
channel_id: StringThe ID of the channel to be mentioned.
style: Option<RichTextStyle2>An object of six optional boolean properties that dictate style: bold, italic, strike, highlight, client_highlight, and unlink.