pub struct RichTextElementDate {
pub timestamp: u64,
pub format: String,
pub url: Option<String>,
pub fallback: Option<String>,
}Expand description
The following are the properties of the date object type in the elements array.
Fields
timestamp: u64A Unix timestamp for the date to be displayed in seconds.
format: StringA template string containing curly-brace-enclosed tokens to substitute your provided timestamp.
url: Option<String>URL to link the entire format string to.
fallback: Option<String>Text to display in place of the date should parsing, formatting or displaying fail.