Struct sfr_types::RichTextElementText
source · pub struct RichTextElementText {
pub text: String,
pub style: Option<RichTextStyle>,
}Expand description
The following are the properties of the text object type in the elements array.
Fields
text: StringThe text shown to the user.
style: Option<RichTextStyle>An object containing four boolean fields, none of which are required: bold, italic, strike, and code.