pub struct RichTextElementUsergroup {
pub usergroup_id: String,
pub style: Option<RichTextStyle2>,
}Expand description
The following are the properties of the usergroup object type in the elements array.
Fields
usergroup_id: StringThe ID of the user group to be mentioned.
style: Option<RichTextStyle2>An object of six optional boolean properties that dictate style: bold, italic, strike, highlight, client_highlight, and unlink.