pub struct RichTextStyle {
pub bold: Option<bool>,
pub code: Option<bool>,
pub italic: Option<bool>,
pub strike: Option<bool>,
}Expand description
An object containing four boolean properties: bold, italic, strike, and code.
Fields
bold: Option<bool>When true, boldens the text in this element. Defaults to false.
code: Option<bool>When true, the text is preformatted in an inline code style. Defaults to `false.
italic: Option<bool>When true, italicizes the text in this element. Defaults to false.
strike: Option<bool>When true, strikes through the text in this element. Defaults to false.