pub struct RichTextStyle2 {
pub bold: Option<bool>,
pub italic: Option<bool>,
pub strike: Option<bool>,
pub highlight: Option<bool>,
pub client_highlight: Option<bool>,
pub unlink: Option<bool>,
}Expand description
An object of six optional boolean properties that dictate style: bold, italic, strike, highlight, client_highlight, and unlink.
Fields
bold: Option<bool>When true, boldens the text in this element. Defaults to false.
italic: Option<bool>When true, italicizes the text in this element. Defaults to false.
strike: Option<bool>When true, strikes through the text in this element. Defaults to false.
highlight: Option<bool>Defaults to false.
client_highlight: Option<bool>Defaults to false.
unlink: Option<bool>Defaults to false.