pub struct ChatPostMessageRequest {Show 14 fields
pub channel: String,
pub content: ChatPostMessageContent,
pub as_user: Option<bool>,
pub icon_emoji: Option<String>,
pub icon_url: Option<String>,
pub link_names: Option<bool>,
pub metadata: Option<String>,
pub mrkdwn: Option<bool>,
pub parse: Option<String>,
pub reply_broadcast: Option<bool>,
pub thread_ts: Option<String>,
pub unfurl_links: Option<bool>,
pub unfurl_media: Option<bool>,
pub username: Option<String>,
}Expand description
The type that represents a request of chat.postMessage.
Fields
channel: StringChannel, private group, or IM channel to send message to.
content: ChatPostMessageContentattachments / blocks / text. One of these arguments is required to describe the content of the message.
as_user: Option<bool>(Legacy) Pass true to post the message as the authed user instead of as a bot.
icon_emoji: Option<String>Emoji to use as the icon for this message.
https://api.slack.com/methods/chat.postMessage#arg_icon_emoji
icon_url: Option<String>URL to an image to use as the icon for this message.
link_names: Option<bool>Find and link user groups.
https://api.slack.com/methods/chat.postMessage#arg_link_names
metadata: Option<String>JSON object with event_type and event_payload fields, presented as a URL-encoded string.
mrkdwn: Option<bool>Disable Slack markup parsing by setting to false.
parse: Option<String>Change how messages are treated.
reply_broadcast: Option<bool>Used in conjunction with thread_ts and indicates whether reply should be made visible to everyone in the channel or conversation.
https://api.slack.com/methods/chat.postMessage#arg_reply_broadcast
thread_ts: Option<String>Provide another message’s ts value to make this message a reply.
https://api.slack.com/methods/chat.postMessage#arg_thread_ts
unfurl_links: Option<bool>Pass true to enable unfurling of primarily text-based content.
https://api.slack.com/methods/chat.postMessage#arg_unfurl_links
unfurl_media: Option<bool>Pass false to disable unfurling of media content.
https://api.slack.com/methods/chat.postMessage#arg_unfurl_media
username: Option<String>Set your bot’s user name.