pub struct FilesUploadRequest {
pub channels: Vec<String>,
pub content: FilesUploadRequestContent,
pub filename: Option<String>,
pub filetype: Option<String>,
pub initial_comment: Option<String>,
pub thread_ts: Option<String>,
pub title: Option<String>,
}Expand description
The type that represents a request of files.upload.
Fields
channels: Vec<String>Comma-separated list of channel names or IDs where the file will be shared.
content: FilesUploadRequestContentFile contents via a POST variable.
filename: Option<String>Filename of file.
filetype: Option<String>initial_comment: Option<String>The message text introducing the file in specified channels.
https://api.slack.com/methods/files.upload#arg_initial_comment
thread_ts: Option<String>Provide another message’s ts value to upload this file as a reply.
title: Option<String>Title of file.