Struct sfr_types::RichTextElementUser
source · pub struct RichTextElementUser {
pub user_id: String,
pub style: Option<RichTextStyle2>,
}Expand description
The following are the properties of the user object type in the elements array.
Fields
user_id: StringThe ID of the user to be mentioned.
style: Option<RichTextStyle2>An object of six optional boolean properties that dictate style: bold, italic, strike, highlight, client_highlight, and unlink.