pub struct RichTextList {
pub style: RichTextListStyle,
pub elements: Vec<RichTextSection>,
pub indent: Option<u64>,
pub offset: Option<u64>,
pub border: Option<u64>,
}Expand description
List element: rich_text_list.
https://api.slack.com/reference/block-kit/blocks#rich_text_list
Fields
style: RichTextListStyleEither bullet or ordered, the latter meaning a numbered list.
elements: Vec<RichTextSection>An array of rich_text_section objects containing two properties: type, which is “rich_text_section”, and elements, which is an array of rich text element objects.
indent: Option<u64>Number of pixels to indent the list.
offset: Option<u64>Number of pixels to offset the list.
border: Option<u64>Number of pixels of border thickness.